@@ -19,23 +19,16 @@ limitations under the License.
 package conformance
 
 import (
+	"context"
 	"testing"
 
 	"knative.dev/eventing/test/conformance/helpers"
-	testlib "knative.dev/eventing/test/lib"
 )
 
-func TestBrokerV1Beta1DataPlaneIngress(t *testing.T) {
-	client := testlib.Setup(t, true, testlib.SetupClientOptionNoop)
-	defer testlib.TearDown(client)
-
-	broker := helpers.BrokerDataPlaneSetupHelper(client, brokerName, brokerNamespace, brokerClass)
-	helpers.BrokerV1Beta1IngressDataPlaneTestHelper(t, client, broker)
+func TestBrokerDataPlaneIngress(t *testing.T) {
+	helpers.BrokerIngressDataPlaneTestHelper(context.Background(), t, brokerClass, brokerTestRunner, helpers.BrokerDataPlaneNamespaceSetupOption(context.Background(), brokerTestRunner.ComponentNamespace))
 }
-func TestBrokerV1Beta1DataPlaneConsumer(t *testing.T) {
-	client := testlib.Setup(t, true, testlib.SetupClientOptionNoop)
-	defer testlib.TearDown(client)
 
-	broker := helpers.BrokerDataPlaneSetupHelper(client, brokerName, brokerNamespace, brokerClass)
-	helpers.BrokerV1Beta1ConsumerDataPlaneTestHelper(t, client, broker)
+func TestBrokerDataPlaneConsumer(t *testing.T) {
+	helpers.BrokerConsumerDataPlaneTestHelper(context.Background(), t, brokerClass, brokerTestRunner, helpers.BrokerDataPlaneNamespaceSetupOption(context.Background(), brokerTestRunner.ComponentNamespace))
 }
